netapp_ontap.models.raid_group API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.raid_group`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class RaidGroupSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the RaidGroup object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `cache_tier: bool GET`

    RAID group is a cache tier

  `degraded: bool GET`

    RAID group is degraded. A RAID group is degraded when at least one disk from that group has failed or is offline.

  `disks: List[RaidGroupDisk] GET`

    The disks field of the raid_group.

  `name: str GET`

    RAID group name

    Example: rg0

  `raid_type: str GET`

    RAID type of the raid group.

    Valid choices:

    - raid_dp
    - raid_tec
    - raid0
    - raid4
  `recomputing_parity: RaidGroupRecomputingParity GET`

    The recomputing_parity field of the raid_group.

  `reconstruct: RaidGroupReconstruct GET`

    The reconstruct field of the raid_group.